@CLAUDE.md Let's create a singleton for constructing CTE clients. Call it WRP_CTE_CLIENT. It simply points to a cte::core::Client. We should also create a singleton for the WRP_RUNTIME_CONFIG, which points to a cte::core::Config. Lastly, we then need to create a method called WRP_CTE_CLIENT_INIT that loads the configuration and calls cte::wore::Client::Create. Look at the core_runtime code's functions for loading the configuration. We should use the WRP_CTE_CLIENT inside the adapters instead of empty wrp::cte::Client constructors. We should remove the wrp::cte::Client from the stat data structure as well, since we now have a singleton for the client and the configuration.